<template>
    <div class="device-info">
        <div class="header">
            <span class="title">设备告警趋势</span>
        </div>

        <div ref="chartRef" style="width: 100%; min-height: calc(100% - 40px)"></div>
    </div>
</template>
<script lang="ts" name="AlarmTrend" setup>
import { useMenuStore } from '@/store/menu';
import * as echarts from 'echarts';
const chartRef = ref<Record<string, any>>({});
const menu = useMenuStore();
let myChart: any = null;

const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        const options = {
            xAxis: {
                type: 'category',
                boundaryGap: false,
            },
            yAxis: {
                type: 'value',
                // boundaryGap: [0, '30%'],
            },
            grid: {
                top: '10%',
                left: '3%',
                right: '4%',
                bottom: '8%',
                containLabel: true,
            },
            series: [
                {
                    type: 'line',
                    smooth: true,
                    // symbol: 'none',
                    lineStyle: {
                        color: '#38B7FF',
                        width: 2,
                    },
                    areaStyle: {
                        color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                            {
                                offset: 0,
                                color: 'rgba(56, 183, 255, 0.8)',
                            },
                            {
                                offset: 1,
                                color: 'rgba(217, 217, 217, 0)',
                            },
                        ]),
                    },
                    data: [
                        ['2019-10-10', 200],
                        ['2019-10-11', 560],
                        ['2019-10-12', 750],
                        ['2019-10-13', 580],
                        ['2019-10-14', 250],
                        ['2019-10-15', 300],
                        ['2019-10-16', 450],
                        ['2019-10-17', 300],
                        ['2019-10-18', 100],
                    ],
                },
            ],
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

watch(
    () => menu.collapsed,
    (newX) => {
        setTimeout(() => {
            myChart.resize();
        }, 300);
    },
);

onMounted(() => {
    handleOptions();
});
</script>
<style scoped lang="less">
.device-info {
    flex: 3;
    height: 100%;
    background: white;
    .header {
        padding: 8px 16px;
        border-bottom: 1px dotted #e6e6e6;
        .title {
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 22px;
            border-left: 3px solid #4277FF;
            padding-left: 8px;
        }
    }
}
</style>
